# PySweeper

Your favorite sweeping game, written in Python.


## Installation

### Clone the repo
```shell
$ git clone https://github.com/cpcloud/pysweeper
```

### Install Dependencies
```shell
$ pip install -r requirements.txt
```

### Install PySweeper

```shell
$ pip install .
```

## Usage
```shell
$ python -m pysweeper
```


## TODO

* Use an actual graph
